# Pokéscreader for SV

ポケットモンスタースカーレット・バイオレット
(以下, ポケモン SV) 向けスクリーン読み取りツール.

[OBS Studio](https://obsproject.com/ja) からポケモン SV の対戦画面を読み取り,
外部の音声合成アプリを通じて情報を読み上げます. 用途として以下を想定しています.

- 視覚情報が使えないプレイヤーのプレイング補助
- 視覚情報だけでは情報把握が難しい対戦初心者のプレイング補助
- 対戦配信における音声情報の拡充によるコンテンツ強化

このドキュメントは, バージョン固有な情報を記録する目的で記述されており,
必要最小限の情報のみを記述しています. 詳しい解説は
[公式サイト](https://takosavi.net/pokescreader-sv/development)
をご確認ください.

## 動作環境

### パソコンの動作条件

- ゲーム映像を取り込むキャプチャボード
- OBS Studio (28.0.0 以上)
    - キャプチャボードを映像キャプチャデバイスとして取り込んであること
- 以下の音声合成アプリのうちいずれか.
    - [棒読みちゃん](https://chi.usamimi.info/Program/Application/BouyomiChan/)
      (HTTP 連携機能があるバージョン)
    - [VOICEVOX](https://voicevox.hiroshiba.jp/)
- 以下の OCR 機能のうちいずれか.
    - Windows OCR 日本語 (Windows 日本語版に標準搭載)
    - [Tesseract OCR](https://github.com/tesseract-ocr/tesseract)

### ゲームの条件

- 日本語セーブデータ
- 対プレイヤー戦
- シングルバトル

## 事前準備

ここには最小限の要件だけ記載しています. 詳しい手順や, 標準ではない連携アプリ
(VOICEVOX, Tesseract OCR) を使用する手順は, 公式サイトの
[導入方法](http://localhost:3000/pokescreader-sv/get-started)
を参照してください.

- ポケモンの設定で「話のはやさ」を「はやい」に設定する.
- OBS Studio の WebSocket サーバを認証ありで起動する.
- 棒読みちゃんの HTTP 連携をポート `50080` で起動する. (初期状態ではできているはず)
- `settings.toml` の `[obs]` セクションのうち, 以下の項目を書き換える.
    - `port`: OBS Studio WebSocket サーバのポート番号
    - `password`: OBS Studio WebSocket サーバのパスワード (半角二重引用符で括る)
    - `source`: OBS Studio 映像キャプチャデバイスのソース名 (半角二重引用符で括る)

準備ができたら, OBS Studio と棒読みちゃんがともに起動している状態で
`pokescreader-sv.exe` を起動します.

## ツールの使い方

実装されている機能の詳細は
[機能リファレンス](http://localhost:3000/pokescreader-sv/reference)
を参照してください. このバージョンで実装されている機能は次の通りです.

### 自動で起動する機能

#### シーン遷移通知

- 選出開始
- 選出終了
- 指示開始

#### 自動読み上げ

- 相手チーム
- 相手 HP 割合
- 味方 HP 現在値, 割合
- ログメッセージ
- テラスタイプ

## 手動で操作する機能

- 相手チーム確認 (O キー)
- 相手チームのタイプ確認 (T キー)
- 相手 HP 確認 (H キー)
- 味方 HP 確認 (A キー)
- 技を読み取り (M キー, 技選択画面またはポケモン選択画面のみ)
- 選択中の技を読み取り (C キー, 技選択画面のみ)
- スクリーンショット保存 (1 キー)

## 設定ファイルの追加設定

- `notification` セクション
    - `engine`: 使用する音声合成エンジン.
      `"bouyomichan"` を指定すると棒読みちゃん,
      `"voicevox"` を指定すると VOICEVOX を使用する. (デフォルト: `"bouyomichan"`)
    - `ally_hp_format`: 味方 HP 読み上げ形式.
      `"numerator"` を指定すると現在値だけ, `"ratio"` で割合だけ,
      `"both"` で両方を読み上げる. (デフォルト: `"both"`)
- `bouyomichan` セクション
    - `speed`: 読み上げスピード設定 (デフォルト: 150)
- `voicevox` セクション
    - `speaker`: 先頭を 0 とする話者のインデックス. (デフォルト: `0`)
    - `volume_scale`: 音量を何倍にするか. (デフォルト: `1.0`)
    - `speed_scale`: 速度を何倍にするか. (デフォルト: `1.5`)
- `ocr` セクション
    - `engine`: 使用する OCR エンジン.
      `"winocr"` を指定すると Windows OCR,
      `"tesseract"` を指定すると Tesseract OCR を使用する.
      `"none"` を指定すると OCR を用いる機能を無効化する. (デフォルト `"winocr"`)
- `routine` セクション
    - `notifies_ally_team`: 味方チームを相手チームの後に読み上げる (デフォルト: `false`)
    - `notifies_log`: ログメッセージを読み上げるか (デフォルト: `true`)
    - `notifies_tera_type`: テラスタイプを読み上げるか (デフォルト: `true`)
- `gui` セクション
    - `uses_buttons`: ボタンを表示するかどうか (デフォルト: `true`)

### 把握している不具合

- シーン遷移通知
    - 技選択で使用できない技 (「ちょうはつ」やこだわりアイテムで制限されている場合など)
      を連打すると, 「指示開始」 と通知されることがあります.
- 相手チーム読み上げ
    - 選出終了後, 画面暗転中に相手チームを読み上げると,
      存在しないポケモンの名前を読み上げるようになることがあります.
    - 実機ではなくシミュレーションでの確認にすぎませんが, 次の読み間違いが発生する可能性があります.
        - アルセウス ノーマル以外 → アルセウス ノーマル
        - イキリンコ グリーンフェザー以外 → イキリンコグリーンフェザー
        - ナミイルカ → イルカマン
- 味方チーム読み上げ
    - 6 匹ではないチームを読み上げる際,
      ポケモンが存在しない個所で不正なポケモン名を読み上げます.
- 相手 HP 割合読み上げ
    - 食べ残しの回復ダメージなど, HP ゲージエフェクトの表示時間が極めて短い場合,
      HP 割合の読み上げができなかったり, 数値が不正確になったりすることがあります.
    - 高頻度にダメージが発生する連続技を使うと, 発話が追いつかないことがあります.
- ログメッセージ読み上げ
    - パーティ選択画面の前後で余計な発話をすることがあります.
    - 選出画面に遷移する直前で余計な発話をすることがあります.
- テラスタイプ読み上げ
    - 「テラスタイプドラゴン」を「テラスタイプひこう」と頻繁に間違える傾向があります.
    - 「テラスタイプこおり」を他のタイプと混同することがあります. 
    - カバルドンなど, 前にせり出したポケモンのテラスタイプ判定が不安定になることがあります.
    - 飛行テラバーストを使用するとテラスタイプを読み上げることがあります.
- 技読み上げ
    - 「のろい」の読み上げが失敗することがあります.
    - Tesseract OCR 使用時, 技が 3 つ以下のときに読み上げを行うと,
      存在しない技を読み上げることがあります.
    - Windows OCR 使用時, 「さいきのいのり」の PP 読み上げが失敗することがあります.
- 選択中の技読み上げ
    - 残り PP が 0 になった技を選択しているとき, 読み上げが失敗します.

## 免責事項

テンプレなお約束ですが, 本アプリの使用によって生じた不利益には関知しません. 自己責任でご利用ください.
特に, 通知内容はできるだけ正確になるよう努めていますが, 間違いを起こすこともあります.
あくまでも参考情報として扱ってください.

# 作者

もち

- X: [@takosavi](https://x.com/takosavi)
- Blog: https://takosavi.hatenablog.com/
- Twitch: https://www.twitch.tv/mochitakosavi
